@@ -29,7 +29,7 @@ def normalize_to_array(x):
 
 
 def meta_from_array(x, ndim=None, dtype=None):
-    """ Normalize an array to appropriate meta object
+    """Normalize an array to appropriate meta object
 
     Parameters
     ----------
@@ -178,6 +178,7 @@ def _check_dsk(dsk):
     if not isinstance(dsk, HighLevelGraph):
         return
 
+    dsk.validate()
     assert all(isinstance(k, (tuple, str)) for k in dsk.layers)
     freqs = frequencies(concat(dsk.dicts.values()))
     non_one = {k: v for k, v in freqs.items() if v != 1}
@@ -349,6 +350,48 @@ def validate_axis(axis, ndim):
     return axis
 
 
+def svd_flip(u, v, u_based_decision=False):
+    """Sign correction to ensure deterministic output from SVD.
+
+    This function is useful for orienting eigenvectors such that
+    they all lie in a shared but arbitrary half-space. This makes
+    it possible to ensure that results are equivalent across SVD
+    implementations and random number generator states.
+
+    Parameters
+    ----------
+
+    u : (M, K) array_like
+        Left singular vectors (in columns)
+    v : (K, N) array_like
+        Right singular vectors (in rows)
+    u_based_decision: bool
+        Whether or not to choose signs based
+        on `u` rather than `v`, by default False
+
+    Returns
+    -------
+
+    u : (M, K) array_like
+        Left singular vectors with corrected sign
+    v:  (K, N) array_like
+        Right singular vectors with corrected sign
+    """
+    # Determine half-space in which all singular vectors
+    # lie relative to an arbitrary vector; summation
+    # equivalent to dot product with row vector of ones
+    if u_based_decision:
+        dtype = u.dtype
+        signs = np.sum(u, axis=0, keepdims=True)
+    else:
+        dtype = v.dtype
+        signs = np.sum(v, axis=1, keepdims=True).T
+    signs = dtype.type(2) * ((signs >= 0) - dtype.type(0.5))
+    # Force all singular vectors into same half-space
+    u, v = u * signs, v * signs.T
+    return u, v
+
+
 def _is_nep18_active():
     class A:
         def __array_function__(self, *args, **kwargs):
