@@ -1,3 +1,4 @@
+from distutils.version import LooseVersion
 import os
 import pytest
 from operator import add, mul
@@ -46,6 +47,15 @@ np = import_or_none("numpy")
 sp = import_or_none("scipy.sparse")
 pd = import_or_none("pandas")
 
+if pd:
+    PANDAS_VERSION = LooseVersion(pd.__version__)
+    PANDAS_GT_100 = PANDAS_VERSION >= LooseVersion("1.0.0")
+
+    if PANDAS_GT_100:
+        import pandas.testing as tm  # noqa: F401
+    else:
+        import pandas.util.testing as tm  # noqa: F401
+
 
 def f1(a, b, c=1):
     pass
@@ -677,8 +687,8 @@ def test_compute_dataframe():
     ddf1 = ddf.a + 1
     ddf2 = ddf.a + ddf.b
     out1, out2 = compute(ddf1, ddf2)
-    pd.testing.assert_series_equal(out1, df.a + 1)
-    pd.testing.assert_series_equal(out2, df.a + df.b)
+    tm.assert_series_equal(out1, df.a + 1)
+    tm.assert_series_equal(out2, df.a + df.b)
 
 
 @pytest.mark.skipif("not dd or not da")
